/*
 * report.h - header file of the report subsystem
 *
 * author: Frank Zirkelbach <frank.zirkelbach@physik.uni-augsburg.de>
 *
 */

#ifndef REPORT_H
#define REPORT_H

static char report_start[]="\
\\pdfoutput=0\n\
\\documentclass[a4paper,11pt]{report}\n\
\\usepackage[activate]{pdfcprot}\n\
\\usepackage{verbatim}\n\
\\usepackage{a4}\n\
\\usepackage{a4wide}\n\
\\usepackage[english,german]{babel}\n\
\\usepackage[latin1]{inputenc}\n\
\\usepackage[T1]{fontenc}\n\
\\usepackage{amsmath}\n\
\\usepackage{ae}\n\
\\usepackage{aecompl}\n\
\\usepackage[dvips]{graphicx}\n\
\\graphicspath{{./}}\n\
\\usepackage{color}\n\
\\usepackage{pstricks}\n\
\\usepackage{pst-node}\n\
\\usepackage{rotating}\n\
\\selectlanguage{english}\n\
\\author{%s}\n\
\\title{%s}\n\
\\begin{document}\n\
\\maketitle\n\
";

static char report_energy[]="\
\\begin{figure}[!h]\n\
\\begin{center}\n\
\\includegraphics[width=16cm]{energy.eps}\n\
\\caption{Kinetic, potential and total energy over time}\n\
\\end{center}\n\
\\end{figure}\n\
";

static char report_pressure[]="\
\\begin{figure}[!h]\n\
\\begin{center}\n\
\\includegraphics[width=16cm]{pressure.eps}\n\
\\caption{Pressure over time}\n\
\\end{center}\n\
\\end{figure}\n\
";

static char report_temperature[]="\
\\begin{figure}[!h]\n\
\\begin{center}\n\
\\includegraphics[width=16cm]{temperature.eps}\n\
\\caption{Temperature over time}\n\
\\end{center}\n\
\\end{figure}\n\
";

static char report_end[]="\
\\end{document}\n\
";

static char e_plot_script[]="\
set autoscale \n\
unset log \n\
unset label \n\
set xtic auto \n\
set ytic auto \n\
set title 'Energy per atom vs. time' \n\
set xlabel 'Time [fs]' \n\
set ylabel 'Energy per atom [eV]' \n\
set terminal postscript eps enhanced color solid lw 1 'Helvetica' 14 \n\
set output 'energy.eps' \n\
plot \"energy\" using 1:2 title 'Kinetic energy' with lines , \"energy\" using 1:3 title 'Potential energy' with lines , \"energy\" using 1:4 title 'Total energy' with lines \
";

static char pressure_plot_script[]="\
set autoscale \n\
unset log \n\
unset label \n\
set xtic auto \n\
set ytic auto \n\
set title 'Pressure vs. time' \n\
set xlabel 'Time [fs]' \n\
set ylabel 'Pressure [bar]' \n\
set terminal postscript eps enhanced color solid lw 1 'Helvetica' 14 \n\
set output 'pressure.eps' \n\
plot \"pressure\" using 1:2 title 'P' with lines , \"pressure\" using 1:3 title '<P>' with lines , \"pressure\" using 1:4 title 'P (global virial)' with lines , \"pressure\" using 1:5 title '<P (global virial)>' with lines \
";

static char temperature_plot_script[]="\
set autoscale \n\
unset log \n\
unset label \n\
set xtic auto \n\
set ytic auto \n\
set title 'Temperature vs. time' \n\
set xlabel 'Time [fs]' \n\
set ylabel 'Temperature [K]' \n\
set terminal postscript eps enhanced color solid lw 1 'Helvetica' 14 \n\
set output 'temperature.eps' \n\
plot \"temperature\" using 1:2 title 'T' with lines , \"temperature\" using 1:3 title '<T>' with lines \
";

#endif
